@@ -45,7 +45,7 @@ impl NativeFun for Float {
 				Ok(Value::from(float))
 			}
 
-			[ other ] => Err(Panic::type_error(other.copy(), "int or float", context.pos)),
+			[ other ] => Err(Panic::type_error(other.copy(), "int, float or string", context.pos)),
 			args => Err(Panic::invalid_args(args.len() as u32, 1, context.pos))
 		}
 	}
